package com.pingshow.doctor.view;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapShader;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.RectF;
import android.graphics.Shader;
import android.graphics.drawable.BitmapDrawable;
import android.util.AttributeSet;
import android.widget.ImageView;

public class URoundedImageView extends ImageView {  
	  
    private Paint mBitmapPaint,mBackgroundPaint;  
      
    private BitmapShader mBitmapShader;  
      
    private RectF mBitmapRect , mRect;  
      
    private int borderWidth;  
      
    private Bitmap mBitmap;  
      
    private Matrix shaderMatrix;  
      
    public URoundedImageView(Context context, AttributeSet attrs,  
            int defStyleAttr) {  
        super(context, attrs, defStyleAttr);  
        init();  
    }  
  
    public URoundedImageView(Context context, AttributeSet attrs) {  
        super(context, attrs);  
        init();  
    }  
  
    public URoundedImageView(Context context) {  
        super(context);  
        init();  
    }  
      
    private void init(){  
        mBitmapPaint = new Paint();  
        mBitmapPaint.setAntiAlias(true);  
          
        mBackgroundPaint = new Paint();  
        mBackgroundPaint.setAntiAlias(true);  
        mBackgroundPaint.setColor(Color.WHITE);  
          
        borderWidth = 5;  
          
        mRect = new RectF();  
        shaderMatrix = new Matrix();  
    }  
      
    @Override  
    protected void onLayout(boolean changed, int left, int top, int right,  
            int bottom) {  
        // TODO Auto-generated method stub  
        super.onLayout(changed, left, top, right, bottom);  
    }  
      
    @Override  
    protected void onDraw(Canvas canvas) {  
        mBitmap = ((BitmapDrawable) getDrawable()).getBitmap();  
          
        if (getWidth() == 0 || getHeight() == 0 || mBitmap == null) {  
            return;  
        }  
        int w = getWidth();  
        int h = getHeight();  
        int radius = Math.min(w, h) / 2;  
          
        canvas.drawCircle(w / 2, h / 2, radius, mBackgroundPaint);  
          
        //传入bitmap初始化位图着色器  
        if (mBitmapShader == null) {  
            mBitmapShader = new BitmapShader(mBitmap, Shader.TileMode.CLAMP,  
                    Shader.TileMode.CLAMP);  
        }  
        if (mBitmapRect == null) {  
            mBitmapRect = new RectF(borderWidth, borderWidth,  
                    mBitmap.getWidth() - borderWidth, mBitmap.getHeight()  
                            - borderWidth);  
        }  
        mBitmapPaint.setShader(mBitmapShader);  
          
        mRect.set(borderWidth, borderWidth, w - borderWidth, h - borderWidth);  
          
        //对bitmap原始图进行缩放  
        shaderMatrix.setRectToRect(mBitmapRect, mRect, Matrix.ScaleToFit.FILL);  
        mBitmapShader.setLocalMatrix(shaderMatrix);  
          
        canvas.drawRoundRect(mRect, radius, radius, mBitmapPaint);  
    }  
  
}  